#
# spec file for package libqt5-qtwayland
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define qt5_snapshot 0
%define libname libQt5WaylandCompositor5
%define base_name libqt5
%define real_version 5.9.4
%define so_version 5.9.4
%define tar_version qtwayland-opensource-src-%{real_version}
Name:           libqt5-qtwayland
Version:        5.9.4
Release:        lp150.2.2
Summary:        Qt 5 Wayland Addon
License:        SUSE-LGPL-2.1-with-digia-exception-1.1 or GPL-3.0
Group:          Development/Libraries/X11
Url:            https://www.qt.io
Source:         https://download.qt.io/official_releases/qt/5.9/%{real_version}/submodules/%{tar_version}.tar.xz
Source1:        baselibs.conf
# PATCH-FIX-OPENSUSE
Patch1:         workaround-null-object.patch
# Pending for upstream 5.9 (https://codereview.qt-project.org/#/c/210552/)
Patch1500:      Dont-recreate-hidden-egl-surfaces.patch
# Pending for upstream 5.9 (https://codereview.qt-project.org/#/c/199123/)
Patch1501:      0001-Handle-maximize-minimize-fullscreen-xdgshellv6.patch
# Patches from upstream dev branch
Patch2000:      0001-Implement-basic-key-composition-support.patch
Patch2001:      0002-Automatically-change-scale-when-entering-a-new-outpu.patch
Patch2002:      0003-Send-SurfaceCreated-and-SurfaceAboutToBeDestroyed-ev.patch
BuildRequires:  fdupes
BuildRequires:  libqt5-qtbase-private-headers-devel >= %{version}
BuildRequires:  libqt5-qtdeclarative-private-headers-devel >= %{version}
BuildRequires:  xz
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(wayland-client) >= 1.1.0
BuildRequires:  pkgconfig(wayland-egl)
BuildRequires:  pkgconfig(wayland-server) >= 1.1.0
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xkbcommon) >= 0.2.0
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Conflicts:      qtwayland
%if %{qt5_snapshot}
#to create the forwarding headers
BuildRequires:  perl
%endif

%description
Qt is a set of libraries for developing applications.

%package devel
Summary:        Qt 5 Wayland Addon
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       libQt5WaylandClient5 = %{version}
Requires:       libQt5WaylandCompositor5 = %{version}
Conflicts:      qtwayland-devel

%description devel
Development package to build Qt-based compositors.

%package private-headers-devel
Summary:        Qt 5 Wayland Addon Non-ABI stable experimental API files
Group:          Development/Libraries/C and C++
BuildArch:      noarch
Requires:       %{name}-devel = %{version}
Requires:       libqt5-qtbase-private-headers-devel

%description private-headers-devel
This package provides private headers of libqt5-qtwayland that are normally
not used by application development and that do not have any ABI or
API guarantees. The packages that build against these have to require
the exact Qt version.

%package -n libQt5WaylandCompositor5
Summary:        Qt 5 Wayland Addon
Group:          Development/Libraries/C and C++
Conflicts:      qtwayland

%description -n libQt5WaylandCompositor5
Qt is a set of libraries for developing applications.

%package -n libQt5WaylandClient5
Summary:        Qt 5 Wayland Addon
Group:          Development/Libraries/C and C++
Conflicts:      qtwayland

%description -n libQt5WaylandClient5
Qt is a set of libraries for developing applications.

%package examples
Summary:        Qt5 wayland examples
Group:          Development/Libraries/X11
Recommends:     %{name}-devel

%description examples
Examples for libqt5-qtwayland module.

%prep
%setup -q -n qtwayland-opensource-src-%{real_version}
%autopatch -p1

%post  -n libQt5WaylandCompositor5 -p /sbin/ldconfig

%postun -n libQt5WaylandCompositor5 -p /sbin/ldconfig

%post  -n libQt5WaylandClient5 -p /sbin/ldconfig

%postun -n libQt5WaylandClient5 -p /sbin/ldconfig

%post   -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%build
%if %{qt5_snapshot}
#force the configure script to generate the forwarding headers (it checks whether .git directory exists)
mkdir .git
%endif
%{_libqt5_qmake} CONFIG+=wayland-compositor
%{make_jobs}

%install
%{qmake5_install}

find %{buildroot}%{_libdir} -type f -name '*la' -print -exec perl -pi -e 's, -L%{_builddir}/\S+,,g' {} \;
find %{buildroot}%{_libdir}/pkgconfig -type f -name '*pc' -print -exec perl -pi -e 's, -L%{_builddir}/\S+,,g' {} \;
# kill .la files
rm -f %{buildroot}%{_libqt5_libdir}/lib*.la

fdupes -s %{buildroot}

%files
%defattr(-,root,root,-)
%doc LICENSE.*
%{_libqt5_bindir}/qtwaylandscanner
%{_libqt5_plugindir}/
%{_libqt5_archdatadir}/qml/QtWayland/

%files -n libQt5WaylandCompositor5
%defattr(-,root,root,-)
%doc  LICENSE.*
%{_libqt5_libdir}/libQt5WaylandCompositor.so.*

%files -n libQt5WaylandClient5
%defattr(-,root,root,-)
%doc LICENSE.*
%{_libqt5_libdir}/libQt5WaylandClient.so.*

%files devel
%defattr(-,root,root,-)
%doc LICENSE.*
%{_libqt5_libdir}/*.prl
%{_libqt5_libdir}/*.so
%{_libqt5_libdir}/pkgconfig/*
%{_libqt5_libdir}/cmake/Qt5*/
%{_libqt5_archdatadir}/mkspecs/modules/*.pr?
%exclude %{_libqt5_includedir}/Qt*/%{so_version}
%{_libqt5_includedir}/Qt*

%files private-headers-devel
%defattr(-,root,root,755)
%doc LICENSE.*
%{_libqt5_includedir}/Qt*/%{so_version}

%files examples
%defattr(-,root,root,755)
%doc LICENSE.*
%{_libqt5_examplesdir}/

%changelog
* Tue Feb 13 2018 fabian@ritter-vogt.de
- Add patch (pending upstream) to implement fullscreen windows for
  xdg-shell v6 (boo#1080447):
  * 0001-Handle-maximize-minimize-fullscreen-xdgshellv6.patch
* Thu Jan 25 2018 fabian@ritter-vogt.de
- Update to 5.9.4:
  * New bugfix release
  * For more details, see
    http://code.qt.io/cgit/qt/qtwayland.git/tree/dist/changes-5.9.4/?h=v5.9.4
* Tue Jan  9 2018 fabian@ritter-vogt.de
- Add patch (pending upstream) to fix destruction of hidden surfaces (kde#381630):
  * Dont-recreate-hidden-egl-surfaces.patch
- Keep workaround-null-object.patch as it can in theory prevent
  crashes and has no effect otherwise
* Mon Jan  1 2018 fabian@ritter-vogt.de
- Add patch from upstream dev branch for compose key support:
  * 0001-Implement-basic-key-composition-support.patch
- Add fixes from upstream dev branch:
  * 0002-Automatically-change-scale-when-entering-a-new-outpu.patch
  * 0003-Send-SurfaceCreated-and-SurfaceAboutToBeDestroyed-ev.patch
* Sat Nov 25 2017 fabian@ritter-vogt.de
- Update to 5.9.3
  * New bugfix release
  * For more details, see:
    http://code.qt.io/cgit/qt/qtwayland.git/tree/dist/changes-5.9.3/?h=v5.9.3
* Sun Oct  8 2017 lbeltrame@kde.org
- Update to 5.9.2
  * For more details please see:
    https://blog.qt.io/blog/2017/10/06/qt-5-9-2-released/
* Thu Sep 14 2017 fabian@ritter-vogt.de
- Add patch to workaround crash due to nullptr deref (kde#381630):
  * workaround-null-object.patch
* Sat Jul  1 2017 lbeltrame@kde.org
- Update to 5.9.1
  * For more details please see:
    http://blog.qt.io/blog/2017/06/30/qt-5-9-1-released/
* Wed May 31 2017 fabian@ritter-vogt.de
- Update to 5.9.0 final
* Wed May 24 2017 fabian@ritter-vogt.de
- Update to 5.9.0 RC:
  * For more details please see:
    http://lists.qt-project.org/pipermail/announce/2017-May/000115.html
    and https://wiki.qt.io/New_Features_in_Qt_5.9
* Wed Dec 14 2016 hrvoje.senjan@gmail.com
- Update to 5.7.1
  * For more details please see:
    https://blog.qt.io/blog/2016/12/14/qt-5-7-1-released/
    and https://www.qt.io/qt5-7/
* Sat Sep 24 2016 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * For more details please see:
    https://www.qt.io/qt5-7/
- Drop dead 0001-partially-revert-505c373.diff
* Wed Jun  8 2016 hrvoje.senjan@gmail.com
- Update to 5.6.1
  * For more details please see:
    http://blog.qt.io/blog/2016/06/08/qt-5-6-1-released/
* Fri Mar 18 2016 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * For more details please see:
    http://blog.qt.io/blog/2016/03/16/qt-5-6-released/
    and https://wiki.qt.io/New_Features_in_Qt_5.6
- Drop adjust_api.diff, we don't need nor want to support Qt 5.3
- Added 0001-partially-revert-505c373.diff: use pkgconfig to gather
  wayland includes
* Fri Oct 16 2015 hrvoje.senjan@gmail.com
- Update to 5.5.1
  * For more details please see:
    http://blog.qt.io/blog/2015/10/15/qt-5-5-1-released/
* Sun Aug 16 2015 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * For more details please see:
    http://blog.qt.io/blog/2015/07/01/qt-5-5-released/
    and https://wiki.qt.io/New_Features_in_Qt_5.5
* Wed Jun  3 2015 hrvoje.senjan@gmail.com
- Update to 5.4.2
  * Bugfix release, for more details please see:
    http://blog.qt.io/blog/2015/06/02/qt-5-4-2-released/
- Drop Run-eventDispatcher-in-QWaylandDisplayforceRoundTrip.patch,
  merged upstream
* Sat May  9 2015 hrvoje.senjan@gmail.com
- Added Run-eventDispatcher-in-QWaylandDisplayforceRoundTrip.patch
* Tue Feb 24 2015 hrvoje.senjan@gmail.com
- Update to 5.4.1
  * For more details please see:
    http://blog.qt.io/blog/2015/02/24/qt-5-4-1-released/
* Wed Dec 10 2014 hrvoje.senjan@gmail.com
- Update to 5.4 Final
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/12/10/qt-5-4-released/
    and http://qt-project.org/wiki/New-Features-in-Qt-5.4
* Thu Nov 27 2014 hrvoje.senjan@gmail.com
- Update to 5.4 RC
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/11/27/qt-5-4-release-candidate-available/
    and http://qt-project.org/wiki/New-Features-in-Qt-5.4
* Fri Oct 17 2014 hrvoje.senjan@gmail.com
- Update to 5.4.0 beta
  * New feature release, please see
  http://blog.qt.digia.com/blog/2014/10/17/qt-5-4-beta-available/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.4
- Added adjust_api.diff, to guard QPA usage found in 5.3 and 5.4
* Mon Sep  8 2014 hrvoje.senjan@gmail.com
- Update to 5.4.0 alpha:
  * Part of the official Qt release
